/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: mp3_tags.cc 723 2007-05-20 13:29:19Z  $

#include "mp3_tags.h"
#include "str_utils.h"

#include <iostream>

using std::string;
using std::ifstream;
using std::cout;

namespace str = net_outlyer::str_utils;

namespace net_outlyer {

namespace mp3 {

// -- ID3v2 Header --

void id3v2header::read(ifstream & in) throw (e_read_failure) {
    in.read(CHARR(id), 3);
    check(in, "header");

    if (0 != memcmp("ID3", CHARR(id), 3)) {
        // Tried to read an ID3v2 tag from a file without it
        throw e_bad_filetype();
    }
    // POST ]-> It looks like a valid file

    in.read(CHARR(version), 2);
    check(in, "header");
    in.read(CHARR(&flags), 1);
    check(in, "header");
    //in.read(CHARR(&tag_size), 4);
    //if (!in.good()) throw 1;
    {
        tag_size = 0;
        for (int i=0; i<4; ++i) {
            uint8_t byte;
            in.read(CHARR(&byte), 1);
            // FIXME: probably incorrect for more than 2 bytes!
            tag_size = (tag_size << 7) + (byte & 0x7f);
        }
    }
}

void id3v2header::dump() const {
    string sid;

    {
        char buffer[4];
        memcpy(buffer, id, 3);
        buffer[3] = 0;
        sid = buffer;
    }

    cout << "Tag Identifier / File Magic: " << sid << "\n";
    cout << "Tag version: " << (int)version[0] << " " << (int)version[1] << "\n";
    cout << "ID3V2 Flags: 0x" << str::pad(str::to_hex(flags), 2, "0",  str::PAD_LEFT) << "\n";
    cout << "Tag size: " << tag_size << std::endl;
}

// -- ID3v1 Header --

void id3v1header::read(ifstream & in) throw (e_read_failure) {
}

} // namespace mp3

} // namespace net_outlyer

/* vim:set ts=4 et ai: */

