/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: mp3_tags.h 733 2007-05-21 18:27:33Z  $

#ifndef ONET_MP3TAGS_H
#define ONET_MP3TAGS_H

#include <fstream>
#include <string>

#include "mp3_common.h"
#include "mp3_element.h"

namespace net_outlyer {

namespace mp3 {

    /*!
     * \brief ID2v2 tag.
     * \note Only meta information is kept, audio tags are ignored.
     * \note Meta information isn't used currently anyway.
     */
    struct id3v2header : public mp3element {
        uint8_t id[3];          //!< "Magic number" of the file (="ID3")
        uint8_t version[2];     //!< Tag version
        uint8_t flags;          //!< Flags of the tag
        uint32_t tag_size;      //!< The tag size

        /*!
         * \brief Read the tag data
         * \throw e_read_failure If a read error occurs
         * \post The get pointer is positioned after the tag
         */
        void read(std::ifstream & input) throw (e_read_failure);

        //! Print the tag information
        void dump() const;
    };

    /*!
     * \brief ID3v1 tag.
     * \note Currently unused
     */
    struct id3v1header : public mp3element {
        void read(std::ifstream & input) throw (e_read_failure);
    };

} // namespace mp3

} // namespace net_outlyer

#endif // ONET_MP3TAGS_H
/* vim:set ts=4 et ai: */


